@@ -101,7 +101,7 @@ static int ay_change_count;
 
 
 static int fading=0,fadetotal;
-int fadetime;
+static int sfadetime;
 
 #define STEREO_BUF_SIZE 1024
 
@@ -565,7 +565,7 @@ for(f=0;f<16;f++)
 for(f=0;f<3;f++)
   ay_tone_high[f]=0;
 ay_tone_subcycles=ay_env_subcycles=0;
-fading=fadetime=0;
+fading=sfadetime=0;
 sound_oldval=sound_oldval_orig=0;
 
 CLOCK_RESET(AY_CLOCK);	/* in case it was CPC before */
@@ -648,7 +648,7 @@ silent_level=sound_buf[fulllen-1];
 /* apply overall fade if we're in the middle of one. */
 if(fading)
   {
-  if(fadetime<=0)
+  if(sfadetime<=0)
     memset(sound_buf,0,fulllen*sizeof(signed short)),silent=1;
   else
     {
@@ -656,12 +656,12 @@ if(fading)
     for(f=0;f<sound_framesiz;f++,ptr++)
       {
       /* XXX kludgey, but needed to avoid overflow */
-      fadetime--;
-      *ptr=(*ptr)*(fadetime>>4)/(fadetotal>>4);
+      sfadetime--;
+      *ptr=(*ptr)*(sfadetime>>4)/(fadetotal>>4);
       if(sound_stereo)
         {
         ptr++;
-        *ptr=(*ptr)*(fadetime>>4)/(fadetotal>>4);
+        *ptr=(*ptr)*(sfadetime>>4)/(fadetotal>>4);
         }
       }
     }
@@ -706,7 +706,7 @@ driver_frame(buf,fulllen);
 void sound_start_fade(int fadetime_in_sec)
 {
 fading=1;
-fadetime=fadetotal=fadetime_in_sec*sound_freq;
+sfadetime=fadetotal=fadetime_in_sec*sound_freq;
 }
 
 
